==> aws-java-sdk-ses-1.10.16-sources.jar: com/amazonaws/services/simpleemail/model/transform/GetSendStatisticsResultStaxUnmarshaller.java <==
/*
 * Copyright 2010-2015 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 * 
 *  http://aws.amazon.com/apache2.0
 * 
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

package com.amazonaws.services.simpleemail.model.transform;

import java.util.Map;
import java.util.Map.Entry;

import javax.xml.stream.events.XMLEvent;

import com.amazonaws.services.simpleemail.model.*;
import com.amazonaws.transform.Unmarshaller;
import com.amazonaws.transform.MapEntry;
import com.amazonaws.transform.StaxUnmarshallerContext;
import com.amazonaws.transform.SimpleTypeStaxUnmarshallers.*;

/**
 * Get Send Statistics Result StAX Unmarshaller
 */
public class GetSendStatisticsResultStaxUnmarshaller implements Unmarshaller<GetSendStatisticsResult, StaxUnmarshallerContext> {

    public GetSendStatisticsResult unmarshall(StaxUnmarshallerContext context) throws Exception {
        GetSendStatisticsResult getSendStatisticsResult = new GetSendStatisticsResult();
        int originalDepth = context.getCurrentDepth();
        int targetDepth = originalDepth + 1;

        if (context.isStartOfDocument()) targetDepth += 2;

        while (true) {
            XMLEvent xmlEvent = context.nextEvent();
            if (xmlEvent.isEndDocument()) return getSendStatisticsResult;

            if (xmlEvent.isAttribute() || xmlEvent.isStartElement()) {
                if (context.testExpression("SendDataPoints/member", targetDepth)) {
                    getSendStatisticsResult.getSendDataPoints().add(SendDataPointStaxUnmarshaller.getInstance().unmarshall(context));
                    continue;
                }
            } else if (xmlEvent.isEndElement()) {
                if (context.getCurrentDepth() < originalDepth) {
                    return getSendStatisticsResult;
                }
            }
        }
    }

    private static GetSendStatisticsResultStaxUnmarshaller instance;
    public static GetSendStatisticsResultStaxUnmarshaller getInstance() {
        if (instance == null) instance = new GetSendStatisticsResultStaxUnmarshaller();
        return instance;
    }
}

==> aws-java-sdk-ses-1.10.52-sources.jar: com/amazonaws/services/simpleemail/model/transform/GetSendStatisticsResultStaxUnmarshaller.java <==
/*
 * Copyright 2010-2016 Amazon.com, Inc. or its affiliates. All Rights
 * Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 *
 *  http://aws.amazon.com/apache2.0
 *
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

package com.amazonaws.services.simpleemail.model.transform;

import java.util.Map;
import java.util.Map.Entry;

import javax.xml.stream.events.XMLEvent;

import com.amazonaws.services.simpleemail.model.*;
import com.amazonaws.transform.Unmarshaller;
import com.amazonaws.transform.MapEntry;
import com.amazonaws.transform.StaxUnmarshallerContext;
import com.amazonaws.transform.SimpleTypeStaxUnmarshallers.*;

/**
 * GetSendStatisticsResult StAX Unmarshaller
 */
public class GetSendStatisticsResultStaxUnmarshaller implements
        Unmarshaller<GetSendStatisticsResult, StaxUnmarshallerContext> {

    public GetSendStatisticsResult unmarshall(StaxUnmarshallerContext context)
            throws Exception {
        GetSendStatisticsResult getSendStatisticsResult = new GetSendStatisticsResult();
        int originalDepth = context.getCurrentDepth();
        int targetDepth = originalDepth + 1;

        if (context.isStartOfDocument())
            targetDepth += 2;

        while (true) {
            XMLEvent xmlEvent = context.nextEvent();
            if (xmlEvent.isEndDocument())
                return getSendStatisticsResult;

            if (xmlEvent.isAttribute() || xmlEvent.isStartElement()) {

                if (context
                        .testExpression("SendDataPoints/member", targetDepth)) {
                    getSendStatisticsResult.getSendDataPoints().add(
                            SendDataPointStaxUnmarshaller.getInstance()
                                    .unmarshall(context));
                    continue;
                }

            } else if (xmlEvent.isEndElement()) {
                if (context.getCurrentDepth() < originalDepth) {
                    return getSendStatisticsResult;
                }
            }
        }
    }

    private static GetSendStatisticsResultStaxUnmarshaller instance;

    public static GetSendStatisticsResultStaxUnmarshaller getInstance() {
        if (instance == null)
            instance = new GetSendStatisticsResultStaxUnmarshaller();
        return instance;
    }
}
